@@ -314,7 +314,7 @@ class ScfClient(AbstractClient):
 
 
     def DeleteReservedConcurrencyConfig(self, request):
-        """删除函数的保留并发配置。
+        """删除函数的最大独占配额配置。
 
         :param request: Request instance for DeleteReservedConcurrencyConfig.
         :type request: :class:`tencentcloud.scf.v20180416.models.DeleteReservedConcurrencyConfigRequest`
@@ -425,6 +425,34 @@ class ScfClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def GetAsyncEventStatus(self, request):
+        """获取函数异步执行事件状态，事件状态保留 3 * 24 小时（从事件完成开始计时）。
+
+        :param request: Request instance for GetAsyncEventStatus.
+        :type request: :class:`tencentcloud.scf.v20180416.models.GetAsyncEventStatusRequest`
+        :rtype: :class:`tencentcloud.scf.v20180416.models.GetAsyncEventStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("GetAsyncEventStatus", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GetAsyncEventStatusResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GetFunction(self, request):
         """该接口获取某个函数的详细信息，包括名称、代码、处理方法、关联触发器和超时时间等字段。
 
@@ -593,8 +621,36 @@ class ScfClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def GetRequestStatus(self, request):
+        """该接口根据指定的查询条件返回函数单个请求运行状态。
+
+        :param request: Request instance for GetRequestStatus.
+        :type request: :class:`tencentcloud.scf.v20180416.models.GetRequestStatusRequest`
+        :rtype: :class:`tencentcloud.scf.v20180416.models.GetRequestStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("GetRequestStatus", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GetRequestStatusResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GetReservedConcurrencyConfig(self, request):
-        """获取函数的保留并发详情。
+        """获取函数的最大独占配额详情。
 
         :param request: Request instance for GetReservedConcurrencyConfig.
         :type request: :class:`tencentcloud.scf.v20180416.models.GetReservedConcurrencyConfigRequest`
@@ -986,7 +1042,7 @@ class ScfClient(AbstractClient):
 
 
     def PutReservedConcurrencyConfig(self, request):
-        """设置函数保留并发
+        """设置函数最大独占配额
 
         :param request: Request instance for PutReservedConcurrencyConfig.
         :type request: :class:`tencentcloud.scf.v20180416.models.PutReservedConcurrencyConfigRequest`
